package com.example.primarycourt.activity.ui.pending;

import android.app.ProgressDialog;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;

import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;

import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.VolleyLog;
import com.android.volley.toolbox.JsonArrayRequest;
import com.example.primarycourt.R;
import com.example.primarycourt.app.AppController;
import com.example.primarycourt.helper.CustomListAdapter;
import com.example.primarycourt.helper.PendingCase;
import com.example.primarycourt.helper.SQLiteHandler;
import com.example.primarycourt.helper.SessionManager;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import static com.example.primarycourt.app.AppConfig.IP_PATH;
import static com.example.primarycourt.app.AppController.TAG;

public class PendingFragment extends Fragment {
    EditText inputSearch_assign;
    private ProgressDialog pDialog;
    private List<PendingCase> caseList = new ArrayList<PendingCase>();
    private ListView listView;
    private CustomListAdapter adapter;
    public static String courtID;
    public static String assigned_to;
    public static int accessID;
    public String case_type;
    public String case_number;
    public String case_year;
    public String filing_date;
    public static String URL_ASSIGMENT_CASE;
    private SQLiteHandler db;
    TextView empty;
    private SessionManager session;



    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        View view = inflater.inflate(R.layout.fragment_pending, container, false);


        listView = view.findViewById(R.id.list_assignment);
        inputSearch_assign = view.findViewById(R.id.inputSearch_assign);
        empty = view.findViewById(android.R.id.empty);

        adapter = new CustomListAdapter(getActivity(), caseList);
        listView.setEmptyView(empty);
        listView.setAdapter(adapter);




        pDialog = new ProgressDialog(getActivity());
        // Showing progress dialog before making http request
        pDialog.setMessage("Loading...");
        pDialog.show();


        db = new SQLiteHandler(getActivity());
        HashMap<String, String> user = db.getUserDetails();

        courtID = user.get("courtID");
//        assigned_to = user.get("uid");

//        URL_ASSIGMENT_CASE = IP_PATH+ "pending_case_assignment.php?courtID="+courtID+"&userID"+assigned_to;
        URL_ASSIGMENT_CASE = IP_PATH+ "pending_case_assignment.php?courtID="+courtID;


        // Creating volley request obj
        JsonArrayRequest movieReq = new JsonArrayRequest(URL_ASSIGMENT_CASE,
                new Response.Listener<JSONArray>() {
                    @Override
                    public void onResponse(JSONArray response) {
                        Log.d(TAG, response.toString());
                        hidePDialog();

                        // Parsing json
                        for (int i = 0; i < response.length(); i++) {
                            try {

                                JSONObject obj = response.getJSONObject(i);
                                PendingCase pending_list = new PendingCase();
                                pending_list.setCaseType(obj.getString("case_type"));
                                pending_list.setThumbnailUrl(obj.getString("img"));
                                pending_list.setCaseNumber((obj.getString("case_number")));
                                pending_list.setCaseYear(obj.getString("case_year"));
                                pending_list.setAppellant((obj.getString("case_appellant")));
                                pending_list.setDefendant(obj.getString("case_defendant"));
                                pending_list.setClaim(obj.getString("case_claim"));
                                pending_list.setFilingDate(obj.getString("filing_date"));


                                caseList.add(pending_list);


                                listView.setOnItemClickListener(new AdapterView.OnItemClickListener(){

                                    public void onItemClick(AdapterView<?> l, View view, int position, long id){
                                        //Put the value
                                        String CaseType = ((TextView) view.findViewById(R.id.case_type)).getText().toString();
                                        String CaseNumber = ((TextView) view.findViewById(R.id.case_number)).getText().toString();
                                        String CaseYear = ((TextView) view.findViewById(R.id.case_year)).getText().toString();
                                        String CaseAppellant = ((TextView) view.findViewById(R.id.appellant)).getText().toString();
                                        String CaseDefendant = ((TextView) view.findViewById(R.id.defendant)).getText().toString();
                                        String CaseClaim = ((TextView) view.findViewById(R.id.case_claim)).getText().toString();
                                        String CaseFilingDate = ((TextView) view.findViewById(R.id.case_filing_date)).getText().toString();

                                        Bundle bundle = new Bundle();
                                        bundle.putString("case_type", CaseType);
                                        bundle.putString("case_number", CaseNumber);
                                        bundle.putString("case_year", CaseYear);
                                        bundle.putString("case_appellant", CaseAppellant);
                                        bundle.putString("case_defendant", CaseDefendant);
                                        bundle.putString("case_claim", CaseClaim);
                                        bundle.putString("filing_date", CaseFilingDate);

                                        assignFragment fragment = new assignFragment();
                                        FragmentManager fragmentManager = getFragmentManager();
                                        FragmentTransaction fragmentTransaction = fragmentManager.beginTransaction();
                                        fragment.setArguments(bundle);

                                        fragmentTransaction.replace(R.id.nav_host_fragment, fragment, fragment.getTag());
                                        fragmentTransaction.commit();

                                    }
                                });

                            } catch (JSONException e) {
                                e.printStackTrace();
                            }

                        }


                        // notifying list adapter about data changes
                        // so that it renders the list view with updated data

                        adapter.notifyDataSetChanged();


                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                VolleyLog.d(TAG, "Error: " + error.getMessage());
                hidePDialog();

            }
        });

        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(movieReq);



        /**
         * Enabling Search Filter
         * */
        inputSearch_assign.addTextChangedListener(new TextWatcher() {

            @Override
            public void beforeTextChanged(CharSequence arg0, int arg1, int arg2, int arg3) {
                // TODO Auto-generated method stub
            }

            @Override
            public void onTextChanged(CharSequence cs, int arg1, int arg2, int arg3) {
                // When user changed the Text
                PendingFragment.this.adapter.getFilter().filter(cs);

            }


            @Override
            public void afterTextChanged(Editable cs) {
                // TODO Auto-generated method stub
                inputSearch_assign.removeTextChangedListener(this);
                inputSearch_assign.addTextChangedListener(this);

                Log.e("Value","After");



            }
        });

        return  view;
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        hidePDialog();
    }

    private void hidePDialog() {
        if (pDialog != null) {
            pDialog.dismiss();
            pDialog = null;
        }
    }


}