package com.example.primarycourt.activity.ui.profile;

import android.app.ProgressDialog;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonArrayRequest;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.example.primarycourt.R;
import com.example.primarycourt.activity.ui.home.HomeFragment;
import com.example.primarycourt.activity.ui.update.DecisionFragment;
import com.example.primarycourt.app.AppConfig;
import com.example.primarycourt.app.AppController;
import com.example.primarycourt.helper.SQLiteHandler;
import com.example.primarycourt.helper.userData;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;

import static android.R.layout.simple_spinner_item;
import static com.example.primarycourt.activity.ui.decided.DecidedFragment.courtID;
import static com.example.primarycourt.app.AppConfig.IP_PATH;


public class ChangeCourtFragment extends Fragment {

    private static final String TAG = DecisionFragment.class.getSimpleName();
    TextView court_name;
    Spinner choose_court;
    Button btnChange_court;
    public static String uuid;
    SQLiteHandler db;
    ProgressDialog pDialog;
    RequestQueue requestQueue;
    private ArrayList<userData> DataList = new ArrayList<userData>();
    private ArrayList<String> court_list = new ArrayList<String>();
    public static String URL_GET_USER_COURTS;
    public static String URL_GET_COURT_ID,GET_COURT_NAME;
    public static String selected_courtID;


    public View onCreateView(LayoutInflater inflater , ViewGroup container ,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        View view = inflater.inflate(R.layout.fragment_change_court , container , false);

        court_name = view.findViewById(R.id.court_name);
        choose_court = view.findViewById(R.id.user_court_list);
        btnChange_court = view.findViewById(R.id.btn_change_court);

        // requestQueue init
        requestQueue = Volley.newRequestQueue(getContext());
        // Progress dialog
        pDialog = new ProgressDialog(getActivity());
        pDialog.setCancelable(false);

        // GET USER FROM SQLITE
        db = new SQLiteHandler(getActivity());
        HashMap<String, String> user = db.getUserDetails();
        uuid = user.get("uid");
        courtID = user.get("courtID");

        getUserCourts();
        getCourtName();


        btnChange_court.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String courtName = String.valueOf(choose_court.getSelectedItem()).trim();

                if(!courtName.isEmpty() && !courtName.equals(getResources().getString(R.string.choose_court))){
                getCourtId(courtName);

                } else{
                    Toast.makeText(getActivity(), (getResources().getString(R.string.fill_all_filed)), Toast.LENGTH_LONG).show();
                }
            }
        });



        return view;
    }

    private void getUserCourts(){

        URL_GET_USER_COURTS = IP_PATH+"get_assigned_court.php?uuid="+uuid;
        // Creating volley request obj
        JsonArrayRequest courtList = new JsonArrayRequest(URL_GET_USER_COURTS,
                new Response.Listener<JSONArray>() {
                    @Override
                    public void onResponse(JSONArray response) {
                        Log.d(TAG, response.toString());
                        hideDialog();

                        court_list.add(getResources().getString(R.string.choose_court));
                        try {
                            for (int i = 0; i < response.length(); i++) {

                                JSONObject obj = response.getJSONObject(i);
                                userData court_details = new userData();
                                court_details.setCourtName(obj.getString("court_name"));

                                DataList.add(court_details);
                            }

                            for (int n = 0; n < DataList.size(); n++){
                                court_list.add(DataList.get(n).getCourtName());
                            }

                            ArrayAdapter<String> spinnerArrayAdapter = new ArrayAdapter<>(getActivity() , simple_spinner_item , court_list);
                            spinnerArrayAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item); // The drop down view
                            choose_court.setAdapter(spinnerArrayAdapter);
                            hideDialog();

                        }catch (JSONException e) {
                            e.printStackTrace();
                        }
                    }
                },
                new Response.ErrorListener() {
                    @Override
                    public void onErrorResponse(VolleyError error) {
                        //displaying the error in toast if occurrs
                        Toast.makeText(getActivity(), error.getMessage(), Toast.LENGTH_SHORT).show();
                    }
                });

        // request queue
        AppController.getInstance().addToRequestQueue(courtList);
    }
    private void getCourtId(String courtName){
        URL_GET_COURT_ID = IP_PATH+"get_court_id.php?court_name="+courtName;
        StringRequest court_info = new StringRequest(Request.Method.GET,URL_GET_COURT_ID,
                new Response.Listener<String>() {

                    @Override
                    public void onResponse(String response) {
                        hideDialog();

                        try {
                            JSONObject obj = new JSONObject(response);
                            String CourtID = obj.getString("courtID");
                            db.updateUserCourt(CourtID,uuid);

                            Toast.makeText(getActivity(), (getResources().getString(R.string.app_court_change)), Toast.LENGTH_LONG).show();

                            Fragment fragment =  new HomeFragment();
                            FragmentManager fragmentManager = getFragmentManager();
                            FragmentTransaction fragmentTransaction = fragmentManager.beginTransaction();
                            fragmentTransaction.replace(R.id.nav_host_fragment, fragment, fragment.getTag());
                            fragmentTransaction.commit();

                        }
                        catch (JSONException e) {
                            e.printStackTrace();
                        }
                    }
                }, new Response.ErrorListener() {
            @Override
            // Handles errors that occur due to Volley
            public void onErrorResponse(VolleyError error) {
                Log.e("Volley", error.getMessage());
                hideDialog();
            }
        });
        requestQueue.add(court_info);
    }
    private void getCourtName(){
        GET_COURT_NAME = AppConfig.IP_PATH+"get_court_name.php?courtID=" + courtID;
        StringRequest user_court_name = new StringRequest(Request.Method.GET,GET_COURT_NAME,
                new Response.Listener<String>() {

                    @Override
                    public void onResponse(String response) {
                        Log.d(TAG, "Login Response: " + response);
                        hideDialog();

                        try {
                            JSONObject obj = new JSONObject(response);
                            String Court_Name = obj.getString("court_name");
                            court_name.setText(Court_Name);
                        }
                        catch (JSONException e) {
                            e.printStackTrace();
                        }
                    }
                }, new Response.ErrorListener() {
            @Override
            // Handles errors that occur due to Volley
            public void onErrorResponse(VolleyError error) {
                Log.e("Volley", error.getMessage());
                hideDialog();
            }
        });
        requestQueue.add(user_court_name);
    }


    private void showDialog() {
        if (!pDialog.isShowing())
            pDialog.show();
    }
    private void hideDialog() {
        if (pDialog.isShowing())
            pDialog.dismiss();
    }
}