package com.example.primarycourt.helper;


import android.app.Activity;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Filter;
import android.widget.Filterable;
import android.widget.TextView;

import com.android.volley.toolbox.ImageLoader;
import com.android.volley.toolbox.NetworkImageView;
import com.example.primarycourt.R;
import com.example.primarycourt.app.AppController;

import java.util.ArrayList;
import java.util.List;

public class CustomListAdapter extends BaseAdapter implements Filterable {
    private Activity activity;
    private LayoutInflater inflater;
    private static List<PendingCase> allItems;
    private static List<PendingCase> caseItems;
    ImageLoader imageLoader = AppController.getInstance().getImageLoader();



    public CustomListAdapter(Activity activity, List<PendingCase> caseItems) {
        this.activity = activity;
        this.allItems = caseItems;
        this.caseItems = caseItems;
    }

    @Override
    public int getCount() {
        return caseItems.size();
    }

    @Override
    public Object getItem(int location) {
        return caseItems.get(location);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {

        if (inflater == null)
            inflater = (LayoutInflater) activity
                    .getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        if (convertView == null)
            convertView = inflater.inflate(R.layout.list_row, null);

        if (imageLoader == null)
            imageLoader = AppController.getInstance().getImageLoader();
        NetworkImageView thumbNail = (NetworkImageView) convertView
                .findViewById(R.id.thumbnail);

        TextView case_id = (TextView) convertView.findViewById(R.id.caseID);
        TextView case_type = (TextView) convertView.findViewById(R.id.case_type);
        TextView case_number = (TextView) convertView.findViewById(R.id.case_number);
        TextView case_year = (TextView) convertView.findViewById(R.id.case_year);
        TextView appellant = (TextView) convertView.findViewById(R.id.appellant);
        TextView defendant = (TextView) convertView.findViewById(R.id.defendant);
        TextView claim = (TextView) convertView.findViewById(R.id.case_claim);
        TextView filing_date = (TextView) convertView.findViewById(R.id.case_filing_date);
        TextView case_magistrate = (TextView) convertView.findViewById(R.id.magistrate);
        TextView decided_date = (TextView) convertView.findViewById(R.id.case_decided_date);
        TextView determination_mode = (TextView) convertView.findViewById(R.id.case_mode_determination);
        TextView case_outcome = (TextView) convertView.findViewById(R.id.case_outcome);
        TextView case_remarks = (TextView) convertView.findViewById(R.id.case_remarks);


        TextView appellant_position = (TextView) convertView.findViewById(R.id.AppellantPosition);
        TextView appellant_age = (TextView) convertView.findViewById(R.id.AppellantAge);
        TextView appellant_gender = (TextView) convertView.findViewById(R.id.AppellantGender);
        TextView appellant_phone = (TextView) convertView.findViewById(R.id.AppellantPhone);
        
        TextView defendant_position = (TextView) convertView.findViewById(R.id.DefendantPosition);
        TextView defendant_age = (TextView) convertView.findViewById(R.id.DefendantAge);
        TextView defendant_gender = (TextView) convertView.findViewById(R.id.DefendantGender);
        TextView defendant_phone = (TextView) convertView.findViewById(R.id.DefendantPhone);

        // getting case data for the row
        PendingCase m = caseItems.get(position);

        case_id.setText(String.valueOf(m.getCaseID()));

        thumbNail.setImageUrl(m.getThumbnailUrl(), imageLoader);

        case_type.setText(m.getCaseType());

        case_number.setText(String.valueOf(m.getCaseNumber()));

        case_year.setText(String.valueOf(m.getCaseYear()));

        appellant.setText(m.getAppellant());

        defendant.setText(String.valueOf(m.getDefendant()));

        claim.setText(String.valueOf(m.getClaim()));

        filing_date.setText(String.valueOf(m.getFilingDate()));

        case_magistrate.setText(String.valueOf(m.getMagistrate()));

        decided_date.setText(m.getDecidedDate());

        determination_mode.setText(String.valueOf(m.getDeterminationMode()));

        case_outcome.setText(String.valueOf(m.getCaseOutcome()));

        case_remarks.setText(String.valueOf(m.getCaseRemarks()));

        appellant_position.setText(String.valueOf(m.getAppellantPosition()));

        appellant_age.setText(String.valueOf(m.getAppellantAge()));

        appellant_gender.setText(String.valueOf(m.getAppellantGender()));

        appellant_phone.setText(String.valueOf(m.getAppellantPhone()));

        defendant_position.setText(m.getDefendantPosition());

        defendant_age.setText(String.valueOf(m.getDefendantAge()));

        defendant_gender.setText(String.valueOf(m.getDefendantGender()));

        defendant_phone.setText(String.valueOf(m.getDefendantPhone()));

        return convertView;
    }

    @Override
    public Filter getFilter() {
        return new Filter() {
            @SuppressWarnings("unchecked")
            @Override
            protected void publishResults(CharSequence constraint, final FilterResults results) {
                if (results.count > 0) {
                    caseItems = (List<PendingCase>) results.values;
                    notifyDataSetChanged();
                }
            }

            @Override
            protected FilterResults performFiltering(final CharSequence constraint) {
                final List<PendingCase> filteredResults = getFilteredResults(constraint);
                final FilterResults results = new FilterResults();
                results.values = filteredResults;
                results.count = filteredResults.size();
                return results;
            }
        };
    }

    private List<PendingCase> getFilteredResults(CharSequence cs) {
        String searchString = String.valueOf(cs).toUpperCase();
        if (searchString.isEmpty()) return allItems;
        List<PendingCase> output = new ArrayList<>();

        for (PendingCase history : allItems) {
            String toCaseNumber = history.getCaseNumber();
            String toCaseType = history.getCaseType();
            String toMagistrate = history.getMagistrate();
            if (toCaseNumber.contains(",")) toCaseNumber = toCaseNumber.replace(",", "");

            if (toCaseNumber.toUpperCase().contains(searchString)) {
                output.add(history);
            }
            else if (toCaseType.toUpperCase().contains(searchString)) {
                output.add(history);
            }
            else if (toMagistrate.toUpperCase().contains(searchString)) {
                output.add(history);
            }
        }
        return output;
    }
}
